
Citing
======

If you find bigger useful in your research, please consider citing it. A suggested
reference is::

    Mark Bell. bigger (Computer Software).
    pypi.python.org/pypi/bigger, 2020. Version <<version number>>

the BibTeX entry::

    @Misc{bigger,
        author = {Bell, Mark},
        title = {bigger (Computer Software)},
        howpublished = {\url{pypi.python.org/pypi/bigger}},
        year = {2020},
        note = {Version <<version number>>}
    }

or the BibItem::

    \bibitem{bigger} Mark Bell: \emph{bigger (Computer Software)},
        \url{pypi.python.org/pypi/bigger}, (2020),
        Version <<version number>>.
